@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: SQLite setup/teardown for tests
 
-our $VERSION = '0.0105';
+our $VERSION = '0.0106';
 
 use Moo;
 use strictures 2;
@@ -28,7 +28,8 @@ has schema => (
 
 
 has dsn => (
-    is => 'lazy',
+    is       => 'lazy',
+    init_arg => undef,
 );
 
 sub _build_dsn {
@@ -38,7 +39,8 @@ sub _build_dsn {
 
 
 has dbh => (
-    is => 'lazy',
+    is       => 'lazy',
+    init_arg => undef,
 );
 
 sub _build_dbh {
@@ -47,7 +49,8 @@ sub _build_dbh {
 }
 
 has _database => (
-    is => 'lazy',
+    is       => 'lazy',
+    init_arg => undef,
 );
 
 sub _build__database {
@@ -109,22 +112,18 @@ Test::SQLite - SQLite setup/teardown for tests
 
 =head1 VERSION
 
-version 0.0105
+version 0.0106
 
 =head1 SYNOPSIS
 
   use DBI;
   use Test::SQLite;
 
-  my $sqlite = Test::SQLite->new(
-    database => '/some/where/production.db',
-  );
+  my $sqlite = Test::SQLite->new(database => '/some/where/production.db');
 
   my $dbh = DBI->connect($sqlite->dsn, '', '');
 
-  $sqlite = Test::SQLite->new(
-    schema => '/some/where/schema.sql',
-  );
+  $sqlite = Test::SQLite->new(schema => '/some/where/schema.sql');
 
   $dbh = $sqlite->dbh;
 
